// src/AuthenticationProvider.tsx
import React2, { createContext } from "react";
import { InteractionType } from "@azure/msal-browser";
import { AuthenticatedTemplate, MsalAuthenticationTemplate, MsalProvider, UnauthenticatedTemplate } from "@azure/msal-react";

// src/hooks/useConfiguration.ts
import { useEffect, useState } from "react";
import { BrowserCacheLocation, PublicClientApplication } from "@azure/msal-browser";

// src/configs/index.ts
var environmentConfig = () => ({
  clientId: process.env["VITE_MSAL_CLIENT_ID"],
  authority: process.env["VITE_MSAL_AUTHORITY"],
  loginRedirectUri: process.env["VITE_MSAL_REDIRECT_URL"],
  logoutRedirectUri: process.env["VITE_MSAL_LOGOUT_REDIRECT_URL"],
  scopes: process.env["VITE_MSAL_SCOPES"],
  cacheLoc: process.env["VITE_MSAL_CACHE_LOCATION"],
  tokenInterval: process.env["VITE_MSAL_TOKEN_INTERVAL"],
  tokenThreshold: process.env["VITE_MSAL_TOKEN_REFRESH_THRESHOLD"]
});
var Constants = {
  SPLIT_COMMA: ",",
  TOKEN_INTERVAL: 36e5,
  TOKEN_THRESHOLD: 300,
  SCOPES: ["User.Read"]
};
var ConstantsMessage = {
  MSG_ENV: "Missing environment configuration",
  MSG_CLIENT_ID: "Missing clientId",
  MSG_AUTH_URL: "Missing authority url",
  MSG_REDIRECT_URL: "Missing redirect url"
};

// src/hooks/useConfiguration.ts
var useConfiguration = (authConfig) => {
  const [config, setConfig] = useState();
  const [options, setOptions] = useState();
  useEffect(() => {
    if (authConfig != null && authConfig.option) {
      setOptions(authConfig.option);
    }
    const clientInstance = authConfig && authConfig.instance ? authConfig.instance : defaultInstance();
    const msalInstance = new PublicClientApplication(clientInstance);
    if (msalInstance) {
      setConfig(msalInstance);
    }
  }, [authConfig]);
  const defaultInstance = () => {
    const env = environmentConfig();
    if (!env)
      throw new Error(ConstantsMessage.MSG_ENV);
    let interval = Constants.TOKEN_INTERVAL;
    let threshold = Constants.TOKEN_THRESHOLD;
    let cacheLoc = BrowserCacheLocation.LocalStorage;
    if (!env.clientId) {
      throw new Error(ConstantsMessage.MSG_CLIENT_ID);
    }
    if (!env.authority) {
      throw new Error(ConstantsMessage.MSG_AUTH_URL);
    }
    if (!env.loginRedirectUri) {
      throw new Error(ConstantsMessage.MSG_REDIRECT_URL);
    }
    if (env.tokenInterval) {
      interval = parseInt(env.tokenInterval);
    }
    if (env.tokenThreshold) {
      threshold = parseInt(env.tokenInterval);
    }
    if (env.cacheLoc) {
      cacheLoc = BrowserCacheLocation[env.cacheLoc];
    }
    setOptions({
      scopes: env.scopes?.split(Constants.SPLIT_COMMA),
      tokenInterval: interval,
      tokenThreshold: threshold
    });
    const defaultConfig = {
      auth: {
        clientId: env.clientId,
        authority: env.authority,
        redirectUri: env.loginRedirectUri,
        postLogoutRedirectUri: env.logoutRedirectUri,
        navigateToLoginRequestUrl: false
      },
      cache: {
        cacheLocation: cacheLoc,
        storeAuthStateInCookie: true
      },
      system: {
        tokenRenewalOffsetSeconds: Constants.TOKEN_THRESHOLD
      }
    };
    return defaultConfig;
  };
  return { config, option: options };
};
var useConfiguration_default = useConfiguration;

// src/components/AuthenticationSuccess.tsx
import React, { useContext as useContext2, useEffect as useEffect2 } from "react";

// src/hooks/useUserAccount.ts
import { useMsal } from "@azure/msal-react";
import { InteractionRequiredAuthError } from "@azure/msal-browser";
import { jwtDecode } from "jwt-decode";
import { useUserClaimService, useUserTokenService, useUserService } from "react.framework.userclaim";
import { useContext } from "react";
var useUserAccount = () => {
  const { instance, accounts } = useMsal();
  const authentication = useContext(AuthenticationContext);
  const { setUserToken, getTokenInfo } = useUserTokenService();
  const { setUserClaims, getUserClaim } = useUserClaimService();
  const { setUserInfo } = useUserService();
  const getUserToken = async () => {
    const token = getTokenInfo();
    if (token)
      return token;
    const accountInfo = await getAcquireTokenSilent();
    if (accountInfo)
      setUserTokenToStore(accountInfo);
    return accountInfo?.accessToken;
  };
  const getAccessToken = async (scopes, key) => {
    const tokenInfo = getUserClaim(key, "");
    if (tokenInfo && tokenInfo != null)
      return tokenInfo.value;
    const accountInfo = await getAcquireTokenSilent(scopes);
    if (accountInfo) {
      const userClaims = [
        { key, value: accountInfo.accessToken ?? "" }
      ];
      setUserClaims(userClaims);
      return accountInfo.accessToken;
    }
    return null;
  };
  const getAcquireTokenSilent = async (scopes) => {
    const authRequest = { account: accounts[0], scopes: Constants.SCOPES };
    if (scopes != null && scopes.length > 0) {
      authRequest.scopes = scopes;
    }
    try {
      const response = await instance.acquireTokenSilent(authRequest);
      return response;
    } catch (err) {
      if (err instanceof InteractionRequiredAuthError) {
        await instance.acquireTokenRedirect(authRequest);
      }
    }
  };
  const setAccountInfoToStore = (accountInfo) => {
    if (accountInfo) {
      setUserTokenToStore(accountInfo);
      setAccessTokenToStore(accountInfo.accessToken);
      const userAccountExtent = accountInfo.account;
      if (userAccountExtent) {
        const userClaims = [
          { key: "name", value: userAccountExtent.name ?? "" },
          { key: "username", value: userAccountExtent.username ?? "" }
        ];
        setUserClaims(userClaims);
      }
    }
  };
  const setUserTokenToStore = (accountInfo) => {
    if (accountInfo) {
      const userToken = {
        tokenId: accountInfo.tokenId,
        refreshToken: accountInfo.accessToken,
        tokenExpirationDate: accountInfo.expiresOn,
        userToken: accountInfo.accessToken
      };
      setUserToken(userToken);
    }
  };
  const setAccessTokenToStore = (accessToken) => {
    if (accessToken) {
      const decodeToken = jwtDecode(accessToken);
      if (decodeToken) {
        const user = {
          id: 1,
          email: decodeToken.upn,
          firstname: decodeToken.family_name,
          lastName: decodeToken.given_name,
          name: decodeToken.name
        };
        setUserInfo(user);
      }
    }
  };
  const setAcquireTokenToStore = async () => {
    const scopes = authentication?.option?.scopes;
    const accountInfo = await getAcquireTokenSilent(scopes);
    if (accountInfo) {
      setAccountInfoToStore(accountInfo);
    }
  };
  const setUserActiveAccount = async () => {
    const currentAccounts = instance.getAllAccounts();
    if (currentAccounts.length > 0) {
      instance.setActiveAccount(currentAccounts[0]);
    }
    setAcquireTokenToStore();
  };
  const refreshAccessToken = async () => {
    const threshold = authentication?.option?.tokenThreshold ?? Constants.TOKEN_THRESHOLD;
    const isExpired = await isTokenExpired(threshold);
    if (!isExpired) {
      setAcquireTokenToStore();
    }
  };
  const isTokenExpired = async (tokenThreshold) => {
    let isExpired = false;
    const token = getTokenInfo();
    if (token) {
      const decodeToken = jwtDecode(token);
      if (decodeToken.exp) {
        const currentTime = Math.floor(Date.now() / 1e3);
        const timeUntilExpiry = decodeToken.exp - currentTime;
        isExpired = timeUntilExpiry <= (tokenThreshold ?? 0);
      }
    }
    return isExpired;
  };
  return { getUserToken, getAccessToken, refreshAccessToken, setUserActiveAccount };
};
var useUserAccount_default = useUserAccount;

// src/components/AuthenticationSuccess.tsx
var AuthenticationSuccess = ({ children }) => {
  const authentication = useContext2(AuthenticationContext);
  const { setUserActiveAccount, refreshAccessToken } = useUserAccount_default();
  useEffect2(() => {
    setUserActiveAccount();
    const option = authentication?.option;
    const interval = setInterval(refreshAccessToken, option?.tokenInterval);
    return () => clearInterval(interval);
  }, []);
  return /* @__PURE__ */ React.createElement(React.Fragment, null, children);
};
var AuthenticationSuccess_default = AuthenticationSuccess;

// src/AuthenticationProvider.tsx
var AuthenticationContext = createContext(null);
var AuthenticationProvider = ({ children, beforeAuthComponent, authConfig }) => {
  const { config, option } = useConfiguration_default(authConfig);
  return config != null ? /* @__PURE__ */ React2.createElement(MsalProvider, { instance: config }, beforeAuthComponent ? /* @__PURE__ */ React2.createElement(React2.Fragment, null, /* @__PURE__ */ React2.createElement(UnauthenticatedTemplate, null, beforeAuthComponent), /* @__PURE__ */ React2.createElement(AuthenticatedTemplate, null, /* @__PURE__ */ React2.createElement(AuthenticationContext.Provider, { value: { option } }, /* @__PURE__ */ React2.createElement(AuthenticationSuccess_default, null, children)))) : /* @__PURE__ */ React2.createElement(React2.Fragment, null, /* @__PURE__ */ React2.createElement(MsalAuthenticationTemplate, { authenticationRequest: { scopes: option?.scopes }, interactionType: InteractionType.Redirect }, /* @__PURE__ */ React2.createElement(AuthenticationContext.Provider, { value: { option } }, /* @__PURE__ */ React2.createElement(AuthenticationSuccess_default, null, children))))) : null;
};
var AuthenticationProvider_default = AuthenticationProvider;

// src/hooks/useMsalAuthentication.ts
import { useMsal as useMsal2 } from "@azure/msal-react";
var useMsalAuthentication = () => {
  const { instance } = useMsal2();
  const loginRedirect = () => {
    instance.loginRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const loginPopup = () => {
    instance.loginPopup().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutRedirect = () => {
    instance.logoutRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutPopup = () => {
    instance.logoutPopup({
      account: instance.getActiveAccount()
    }).catch((error) => {
      throw new Error(error);
    });
  };
  return { loginRedirect, loginPopup, logoutRedirect, logoutPopup };
};
var useMsalAuthentication_default = useMsalAuthentication;

// src/hooks/useAuthenticated.ts
import { useIsAuthenticated } from "@azure/msal-react";
var useAuthenticated = () => {
  const isAuthenticated = useIsAuthenticated();
  return isAuthenticated;
};
var useAuthenticated_default = useAuthenticated;
export {
  AuthenticationProvider_default as AuthenticationProvider,
  useUserAccount_default as useAccount,
  useAuthenticated_default as useAuthenticated,
  useMsalAuthentication_default as useAuthentication
};
